Actions, Resources, and Condition Keys for Amazon DynamoDB Accelerator (DAX) - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon DynamoDB Accelerator (DAX).
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

# Actions, Resources, and Condition Keys for Amazon DynamoDB Accelerator (DAX)

Amazon DynamoDB Accelerator (DAX) (service prefix: `dax`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon DynamoDB Accelerator (DAX)
- Resources Defined by Amazon DynamoDB Accelerator (DAX)
- Condition Keys for Amazon DynamoDB Accelerator (DAX)

## Actions Defined by Amazon DynamoDB Accelerator (DAX)

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
BatchGetItem | The BatchGetItem action returns the attributes of one or more items from one or more tables. | Read | application* |  |
BatchWriteItem | The BatchWriteItem action operation puts or deletes multiple items in one or more tables. | Write | application* |  |
ConditionCheckItem | The ConditionCheckItem operation checks the existence of a set of attributes for the item with the given primary key | Read | application* |  |
CreateCluster | The CreateCluster action creates a DAX cluster. | Write | application* |  | dax:CreateParameterGroup dax:CreateSubnetGroup ec2:CreateNetworkInterface ec2:DeleteNetworkInterface ec2:DescribeNetworkInterfaces ec2:DescribeSecurityGroups ec2:DescribeSubnets ec2:DescribeVpcs iam:GetRole iam:PassRole
CreateParameterGroup | The CreateParameterGroup action creates collection of parameters that you apply to all of the nodes in a DAX cluster. | Write |  |  |
CreateSubnetGroup | The CreateSubnetGroup action creates a new subnet group. | Write |  |  |
DecreaseReplicationFactor | The DecreaseReplicationFactor action removes one or more nodes from a DAX cluster. | Write | application* |  |
DeleteCluster | The DeleteCluster action deletes a previously provisioned DAX cluster. | Write | application* |  |
DeleteItem | The DeleteItem action deletes a single item in a table by primary key. | Write | application* |  |
| dax:EnclosingOperation |
DeleteParameterGroup | The DeleteParameterGroup action deletes the specified parameter group. | Write |  |  |
DeleteSubnetGroup | The DeleteSubnetGroup action deletes a subnet group. | Write |  |  |
DescribeClusters | The DescribeClusters action returns information about all provisioned DAX clusters. | List | application |  |
DescribeDefaultParameters | The DescribeDefaultParameters action returns the default system parameter information for DAX. | List |  |  |
DescribeEvents | The DescribeEvents action returns events related to DAX clusters and parameter groups. | List |  |  |
DescribeParameterGroups | The DescribeParameterGroups action returns a list of parameter group descriptions. | List |  |  |
DescribeParameters | The DescribeParameters action returns the detailed parameter list for a particular parameter group. | Read |  |  |
DescribeSubnetGroups | The DescribeSubnetGroups action returns a list of subnet group descriptions. | List |  |  |
GetItem | The GetItem action returns a set of attributes for the item with the given primary key. | Read | application* |  |
| dax:EnclosingOperation |
IncreaseReplicationFactor | The IncreaseReplicationFactor action adds one or more nodes to a DAX cluster. | Write | application* |  |
ListTags | The ListTags action returns a list all of the tags for a DAX cluster. | Read | application* |  |
PutItem | The PutItem action creates a new item, or replaces an old item with a new item. | Write | application* |  |
| dax:EnclosingOperation |
Query | The Query action finds items based on primary key values. You can query any table or secondary index that has a composite primary key (a partition key and a sort key). | Read | application* |  |
RebootNode | The RebootNode action reboots a single node of a DAX cluster. | Write | application* |  |
Scan | The Scan action returns one or more items and item attributes by accessing every item in a table or a secondary index. | Read | application* |  |
TagResource | The TagResource action associates a set of tags with a DAX resource. | Tagging | application* |  |
UntagResource | The UntagResource action removes the association of tags from a DAX resource. | Tagging | application* |  |
UpdateCluster | The UpdateCluster action modifies the settings for a DAX cluster. | Write | application* |  |
UpdateItem | The UpdateItem action edits an existing item's attributes, or adds a new item to the table if it does not already exist. | Write | application* |  |
| dax:EnclosingOperation |
UpdateParameterGroup | The UpdateParameterGroup action modifies the parameters of a parameter group. | Write |  |  |
UpdateSubnetGroup | The UpdateSubnetGroup action modifies an existing subnet group. | Write |  |  |

## Resources Defined by Amazon DynamoDB Accelerator (DAX)

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table.

Resource Types | ARN | Condition Keys
--- | --- | ---
application | `arn:${Partition}:dax:${Region}:${Account}:cache/${ClusterName}` |

## Condition Keys for Amazon DynamoDB Accelerator (DAX)

Amazon DynamoDB Accelerator (DAX) defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table.

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference.

Condition Keys | Description | Type
--- | --- | ---
dax:EnclosingOperation | Used to block Transactions APIs calls and allow the non-Transaction APIs calls and vice-versa. | String

On this page:

- Actions Defined by Amazon DynamoDB Accelerator (DAX)
- Resources Defined by Amazon DynamoDB Accelerator (DAX)
- Condition Keys for Amazon DynamoDB Accelerator (DAX)

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more